==> openttd-1.9.0-beta1-docs.tar.tar: openttd-1.9.0-beta1-docs/html/db/db6/gui_8h.js <==
var gui_8h =
[
    [ "HandleOnEditText", "db/db6/gui_8h.html#a41a1cdfe4b8a1bd9be4a95bc0c1ada45", null ],
    [ "InitializeGUI", "db/db6/gui_8h.html#a9671cb87f0894a444d0c4e106dc98cdc", null ],
    [ "ShowAboutWindow", "db/db6/gui_8h.html#a54e66f072f31e520df37d61ea70d8f5e", null ],
    [ "ShowBuildAirToolbar", "db/db6/gui_8h.html#a79d0cf993b19861bd6d7babd41c06061", null ],
    [ "ShowBuildBridgeWindow", "db/db6/gui_8h.html#a71edf4d3c47bd9624c2ac6c2ac0c1855", null ],
    [ "ShowBuildDocksScenToolbar", "db/db6/gui_8h.html#a83af2cfdbb0d1c905262079c4e1c7757", null ],
    [ "ShowBuildDocksToolbar", "db/db6/gui_8h.html#ad6d600361628a4cf7e107306cca924c9", null ],
    [ "ShowBuildIndustryWindow", "db/db6/gui_8h.html#ad04875507288b140b2849dc90040fd8b", null ],
    [ "ShowBuildTreesToolbar", "db/db6/gui_8h.html#a3821e76478d9a9ca53342f8d0f8d633e", null ],
    [ "ShowEstimatedCostOrIncome", "db/db6/gui_8h.html#a665b3645361a97c5e266c44d2422e61a", null ],
    [ "ShowExtraViewPortWindow", "db/db6/gui_8h.html#a25ae9deb10a2b770616cb9685a2af311", null ],
    [ "ShowExtraViewPortWindowForTileUnderCursor", "db/db6/gui_8h.html#a85e2e376b4a8ad5cea2966cd018d4e47", null ],
    [ "ShowFoundTownWindow", "db/db6/gui_8h.html#a5ad009f6f309079cb2d7174c7f14c3f5", null ],
    [ "ShowGameOptions", "db/db6/gui_8h.html#af487449e7f642d3ab0a977a042027bda", null ],
    [ "ShowGameSettings", "db/db6/gui_8h.html#ab8c4fab0620f49f44008aacd2cd6b81b", null ],
    [ "ShowGenerateLandscape", "db/db6/gui_8h.html#a33469c433e13f05d92c4e5eec5168a69", null ],
    [ "ShowGoalQuestion", "db/db6/gui_8h.html#a48888219587d2cedef18a1c014e6933c", null ],
    [ "ShowGoalsList", "db/db6/gui_8h.html#a1e381fb2b114d4f4ac2a24b1cac3c4a1", null ],
    [ "ShowHeightmapLoad", "db/db6/gui_8h.html#aca5ed8c83b93ac2f3652a5fb8909fd55", null ],
    [ "ShowIndustryCargoesWindow", "db/db6/gui_8h.html#a0acb8f259cf3dcb8f84fbef9f3f5ecd7", null ],
    [ "ShowIndustryDirectory", "db/db6/gui_8h.html#aa751757e3348c38f33ea8aa648ca4c62", null ],
    [ "ShowLandInfo", "db/db6/gui_8h.html#a8a343ec581683c3c8f2fab2cdafffc65", null ],
    [ "ShowMusicWindow", "db/db6/gui_8h.html#acac7fa266bb5c5e91e747ef0edcf3823", null ],
    [ "ShowOrdersWindow", "db/db6/gui_8h.html#a175521f0f2e41d334b12c28d727dac81", null ],
    [ "ShowStoryBook", "db/db6/gui_8h.html#ac96a9ac92890837a67981c0427cba1e0", null ],
    [ "ShowSubsidiesList", "db/db6/gui_8h.html#a84be7823dc24ed59a6f5c5194a397c27", null ],
    [ "ShowTownDirectory", "db/db6/gui_8h.html#a35b65b04eb22c054543e5a813169f29e", null ]
];

==> openttd-1.11.0-beta1-docs.tar.tar: openttd-1.11.0-beta1-docs/html/db/db6/gui_8h.js <==
var gui_8h =
[
    [ "InitializeGUI", "db/db6/gui_8h.html#a9671cb87f0894a444d0c4e106dc98cdc", null ],
    [ "ShowAboutWindow", "db/db6/gui_8h.html#a54e66f072f31e520df37d61ea70d8f5e", null ],
    [ "ShowBuildAirToolbar", "db/db6/gui_8h.html#a79d0cf993b19861bd6d7babd41c06061", null ],
    [ "ShowBuildBridgeWindow", "db/db6/gui_8h.html#a71edf4d3c47bd9624c2ac6c2ac0c1855", null ],
    [ "ShowBuildDocksScenToolbar", "db/db6/gui_8h.html#a83af2cfdbb0d1c905262079c4e1c7757", null ],
    [ "ShowBuildDocksToolbar", "db/db6/gui_8h.html#ad6d600361628a4cf7e107306cca924c9", null ],
    [ "ShowBuildIndustryWindow", "db/db6/gui_8h.html#ad04875507288b140b2849dc90040fd8b", null ],
    [ "ShowBuildTreesToolbar", "db/db6/gui_8h.html#a3821e76478d9a9ca53342f8d0f8d633e", null ],
    [ "ShowEstimatedCostOrIncome", "db/db6/gui_8h.html#a665b3645361a97c5e266c44d2422e61a", null ],
    [ "ShowExtraViewportWindow", "db/db6/gui_8h.html#ab1a353c92e0cc1a98674c9f2cfef2b29", null ],
    [ "ShowExtraViewportWindowForTileUnderCursor", "db/db6/gui_8h.html#a8c887bbc76d14f227a034f181a89dbdc", null ],
    [ "ShowFoundTownWindow", "db/db6/gui_8h.html#a5ad009f6f309079cb2d7174c7f14c3f5", null ],
    [ "ShowGameOptions", "db/db6/gui_8h.html#af487449e7f642d3ab0a977a042027bda", null ],
    [ "ShowGameSettings", "db/db6/gui_8h.html#ab8c4fab0620f49f44008aacd2cd6b81b", null ],
    [ "ShowGenerateLandscape", "db/db6/gui_8h.html#a33469c433e13f05d92c4e5eec5168a69", null ],
    [ "ShowGoalQuestion", "db/db6/gui_8h.html#a48888219587d2cedef18a1c014e6933c", null ],
    [ "ShowGoalsList", "db/db6/gui_8h.html#a1e381fb2b114d4f4ac2a24b1cac3c4a1", null ],
    [ "ShowHeightmapLoad", "db/db6/gui_8h.html#aca5ed8c83b93ac2f3652a5fb8909fd55", null ],
    [ "ShowIndustryCargoesWindow", "db/db6/gui_8h.html#a0acb8f259cf3dcb8f84fbef9f3f5ecd7", null ],
    [ "ShowIndustryDirectory", "db/db6/gui_8h.html#aa751757e3348c38f33ea8aa648ca4c62", null ],
    [ "ShowLandInfo", "db/db6/gui_8h.html#a8a343ec581683c3c8f2fab2cdafffc65", null ],
    [ "ShowMusicWindow", "db/db6/gui_8h.html#acac7fa266bb5c5e91e747ef0edcf3823", null ],
    [ "ShowOrdersWindow", "db/db6/gui_8h.html#a175521f0f2e41d334b12c28d727dac81", null ],
    [ "ShowStoryBook", "db/db6/gui_8h.html#ac96a9ac92890837a67981c0427cba1e0", null ],
    [ "ShowSubsidiesList", "db/db6/gui_8h.html#a84be7823dc24ed59a6f5c5194a397c27", null ],
    [ "ShowTownDirectory", "db/db6/gui_8h.html#a35b65b04eb22c054543e5a813169f29e", null ]
];
